@@ -58,7 +58,6 @@ class ApiBase:  # pylint: disable=too-few-public-methods
         self.token = token
         self.proxies = proxies
 
-
     @staticmethod
     def _get_tg_api_method_name(py_style_method_name):
         """Get Telegram API method name from python method name."""
@@ -139,12 +138,6 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
     def __init__(self, token: str, proxies: Optional[dict] = None):
         super().__init__(token=token, proxies=proxies)
 
-    @property
-    def public_ip(self) -> str:
-        """Get public ip address."""
-        return requests.get('https://checkip.amazonaws.com',
-                            proxies=self.proxies).text.strip()
-
     def set_chat_photo(
             self,
             chat_id: Union[int, str],
